pub enum SolveError {
Element(ElementModelError),
Partition(String),
Krylov(KrylovError),
FloatingSubdomain {
part: usize,
removed: usize,
},
SingularSubdomain(usize),
SingularInterior(usize),
SingularCoarseProblem,
}Expand description
Possible errors encountered when solving with FETI.
Variants
Element(ElementModelError)
Downstream error from an element.
Partition(String)
The partition does not describe the model it is meant to decompose.
Krylov(KrylovError)
Downstream error from the dual PCG.
FloatingSubdomain
A subdomain left with some rigid-body modes free.
SingularSubdomain(usize)
A subdomain with some part of it still free to move.
SingularInterior(usize)
The interior of a subdomain, away from the interface, is singular.
SingularCoarseProblem
The assembled corner problem is singular.